==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/soda/engines/db4o/STDb4o.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.io;
using com.db4o.query;
using com.db4o.test.soda;
using com.db4o;
namespace com.db4o.test.soda.engines.db4o {

   public class STDb4o : STEngine {
      
      public STDb4o() : base() {
      }
      private String FILE = "soda.yap";
      
      public static void Main(String[] arguments) {
         JavaSystem._out.println(Db4o.version());
      }
      private com.db4o.ObjectContainer con;
      
      public void reset() {
         new File(FILE).delete();
      }
      
      public Query query() {
         return con.query();
      }
      
      public void open() {
         Db4o.configure().messageLevel(-1);
         Db4o.configure().activationDepth(7);
         con = Db4o.openFile(FILE);
      }
      
      public void close() {
         con.close();
      }
      
      public void store(Object obj) {
         con.set(obj);
      }
      
      public void commit() {
         con.commit();
      }
      
      public void delete(Object obj) {
         con.delete(obj);
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/soda/engines/db4o/STDb4o.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.io;
using com.db4o.query;
using com.db4o.test.soda;
using com.db4o;
namespace com.db4o.test.soda.engines.db4o {

   public class STDb4o : STEngine {
      
      public STDb4o() : base() {
      }
      private String FILE = "soda.yap";
      
      public static void Main(String[] arguments) {
         JavaSystem._out.Println(Db4o.Version());
      }
      private com.db4o.ObjectContainer con;
      
      public void Reset() {
         new File(FILE).Delete();
      }
      
      public Query Query() {
         return con.Query();
      }
      
      public void Open() {
         Db4o.Configure().MessageLevel(-1);
         Db4o.Configure().ActivationDepth(7);
         con = Db4o.OpenFile(FILE);
      }
      
      public void Close() {
         con.Close();
      }
      
      public void Store(Object obj) {
         con.Set(obj);
      }
      
      public void Commit() {
         con.Commit();
      }
      
      public void Delete(Object obj) {
         con.Delete(obj);
      }
   }
}
